#
# spec file for package fuse-overlayfs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fuse-overlayfs
VCS: https://src.suse.de/SLFO-pool/fuse-overlayfs?trackingbranch=main#5559f4f0a4d43b1744656c15ef81164014f28759c0a1f880970971e89770a8d0
Version:        1.15
Release:        160000.1.3
Summary:        FUSE implementation for overlayfs
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://github.com/containers/fuse-overlayfs
Source0:        https://github.com/containers/fuse-overlayfs/archive/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse3-devel
BuildRequires:  gcc

%description
An implementation of overlay+shiftfs in FUSE for rootless containers.

%prep
%autosetup -p1

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules

%make_build

%install
%make_install INSTALL="install -p"

%files
# Binaries
%{_bindir}/fuse-overlayfs
%doc README.md
%license COPYING
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sat May 17 2025 andreas.stieger@gmx.de
- update to 0.15:
  * main: lookup upperdir only for created directories
  * main: allow escaped colons in directory paths
  * main: use extended override xattr to support devices
  * remove unsupported option "lazytime"
* Mon Feb 10 2025 pgajdos@suse.com
- version update to 1.14
  * isolate security xattrs for STAT_OVERRIDE_CONTAINERS. Prefix all security xattrs with XATTR_CONTAINERS_OVERRIDE_PREFIX.
  * prefer user.containers.override_stat over user.fuseoverlayfs.
  * do not force -1 for owner overriding extended attributes. Otherwise the value is written to the override extended attribute.
  * fix file owner retrieval for chmod.
  * honor umask with xattr_permissions.
  * honor mode for devices with xattr_permissions.
  * propagate extended attributes permissions with copyup.
* Tue Nov 21 2023 dmueller@suse.com
- update to 1.13:
  * fix a performance issue when dealing with big directories.
* Sun Jun 11 2023 dmueller@suse.com
- update to 1.12:
  * change license to GPL-2.0-or-later.
  * main: if a lower layer doesn't support ACLs do not enable
    them.
* Sun Dec  4 2022 dmueller@suse.com
- update to 1.10:
  * main: use /proc/self/fd to read xattrs.
  * main: inherit ACLs for new files/dirs.
  * main: fix passing noatime.
  * main: add checks for valid /proc mount.
  * main: fix copy_file_range for deleted files.
  * main: fix creating links of just deleted files.
  * main: fix setting attributes on file without permissions.
  * main: ignore EOVERFLOW when copying xattrs.
  * main: set the correct value for RENAME_NOREPLACE when it is not already
    defined in the system headers.
  * main: create source whiteout only when needed
  * main: fix missing source whiteout when destination is whiteout
  * main: fix lookup if underlying path is a symlink, but a directory on a
    upper directory.
  * main: fix race when looking up an inode that was renamed.
  * main: fix type used for ioctl.
  * main: honor user.overlay. xattrs.  Native overlay uses user.overlay to
    store the overlay metadata instead of trusted.overlay.
  * main: add a mount flag to disable ACLs.
* Tue Sep 28 2021 kkaempf@suse.com
- Update to version 1.7.1
  * set FUSE_CAP_POSIX_ACL only when it is supported by FUSE.
  * treat statx failure with EINVAL as ENOSYS, so that the fallback
    is attempted.
- Update to version 1.7.0
  * fix read xattrs for device files
  * don't create whiteout files in opaque dirs.
  * fix reading files when running with euid != 0.
  * enable POSIX ACLs.
- Update to version 1.6.0
  * fix an invalid access when filtering internal xattrs that could
    deal to a segfault.
- Update to version 1.5.0
  * honor FUSE_OVERLAYFS_DISABLE_OVL_WHITEOUT also for renames
  * use strncpy instead of strcpy
  * fix renameat2(RENAME_NOREPLACE) on older kernels that lack
    device whiteouts for unprivileged users.
  * fix creating a symlink on top of a removed file.
  * fix copyup of xattrs longer than 256 bytes.
* Mon Feb 22 2021 idonmez@suse.com
- Update to version 1.4.0
  * add squash_to_uid and squash_to_gid
  * add squash_to_root mount option.
  * honor option "volatile".
  * when writing mode to xattr, create files with mode 0755.
  * support ID mapping when using xattr permissions.
  * allow opening not accessible but still referenced files.
  * invalidate directory cache on create/rename.
  * fix segfault if no mountpoint specified
  * fix file_exists_at musl compatibility
  * introduce extended attribute to override gid/uid/mode.
  * support writing uid/gid/mode to an extended attribute.
  * fix a memory leak, where inodes are maintained in memory
    even if not needed.
* Sun Aug 16 2020 dmueller@suse.com
- udpate to 1.1.2 (bsc#1175821)
  - fix build issues with libmusl.
  - fix memory leak when creating whiteout files.
  - fix lookup for overflow uid when it is different than the overflow gid.
* Wed Jun 24 2020 rhafer@suse.com
- Update to v1.1.0
  - use openat2(2) when available.
  - accept "ro" as mount option.
  - fix set mtime for a symlink.
  - fix some issues reported by static analysis.
  - fix potential infinite loop on a short read.
  - fix creating a directory if the destination already exists
    in the upper layer.
* Mon Apr 20 2020 sgrunert@suse.com
- Update to v1.0.0
  - Fix portability issue to 32 bits architectures
* Tue Mar 17 2020 sgrunert@suse.com
- Update to v0.7.8
  - report correctly the number of links for a directory also for
    subsequent stat calls
  - stop looking up the ino in the lower layers if the file could
    not be opened
* Wed Mar  4 2020 sgrunert@suse.com
- Update to v0.7.7
  - make sure the destination is deleted before doing a rename(2).
    It prevents a left over directory to cause delete to fail with
    EEXIST.
  - honor --debug.
* Tue Feb  4 2020 sgrunert@suse.com
- Update to v0.7.6 (bsc#1160460)
  - do not look in lower layers for the ino if there is no origin
    xattr set
  - attempt to use the file path if the operation on the fd fails
    with ENXIO
* Mon Jan 20 2020 sgrunert@suse.com
- Update to v0.7.5
  - do not expose internal xattrs through listxattr and getxattr
* Fri Jan 17 2020 sgrunert@suse.com
- Update to v0.7.4
  - fix fallocate for deleted files.
  - ignore O_DIRECT.  It causes issues with libfuse not using an
    aligned buffer, causing write(2) to fail with EINVAL.
  - on copyup, do not copy the opaque xattr.
  - fix a wrong lookup for whiteout files, that could happen on a
    double unlink.
* Thu Jan  9 2020 sgrunert@suse.com
- Update to v0.7.3
  - fix build with -fno-common
  - fix possible segmentation fault in direct_fsync()
  - use the data store to create missing whiteouts
  - after a rename, force a directory reload
* Tue Dec 17 2019 sgrunert@suse.com
- Update to v0.7.2
  - introduce inodes cache
  - correctly read inode for unix sockets
  - avoid hash map lookup when possible
  - use st_dev for the ino key
  - check whether writeback is supported
  - set_attrs: don't require write to S_IFREG
  - ioctl: do not reuse fi->fh for directories
  - fix skip whiteout deletion optimization
  - store the new mode after chmod
* Mon Aug 19 2019 sgrunert@suse.com
- Update to v0.5.1
  - support fuse writeback cache and enable it by default
  - update to latest gnulib
  - add option to disable fsync
  - add option to disable xattrs
  - add option to skip ino number check in lower layers
  - fix fd validity check
  - fix memory leak
  - fix read after free
  - fix type for flistxattr return
  - fix warnings reported by lgtm.com
  - enable parallel dirops
* Mon Jun 17 2019 sgrunert@suse.com
- Update to v0.4.1 (bsc#1137860):
  - create_directory: do not redeclare variable buf
  - fuse-overlayfs: accept option "dev"
  - fuse-overlayfs: add check to readdir for the node parent
  - fuse-overlayfs: add cleanup for layers
  - fuse-overlayfs: drop usage of static arrays for paths
  - fuse-overlayfs: refactor some xattrs common code
  - fuse-overlayfs: start using GCC autocleanup
  - fuse-overlayfs: use cleanup function for initializing node
  - fuse-overlays: fix interaction of unlink(2) with readdir(2)
  - main: add missing debug messages
  - main: do the unlink only after we created the temporary file
  - main: fix a fd leak
  - main: ignore EINVAL when copying xattrs
  - setattr: use fd from fi->fh for ftruncate() whenever possible
* Thu Mar 28 2019 fcastelli@suse.com
- Create initial package for version 0.3
